# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NON_LOCAL_SUPER_RESOLUTION_METADATA = Metadata(
    id="6ff1af6734242879ff8b30bf0db9b599017faa19.boutiques",
    name="NonLocalSuperResolution",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class NonLocalSuperResolutionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `non_local_super_resolution(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    superresoluted_output: OutputPathType
    """The superresoluted output image."""


def non_local_super_resolution(
    input_image: InputPathType,
    output: InputPathType,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    interpolated_image: InputPathType | None = None,
    reference_image: InputPathType | None = None,
    patch_radius: typing.Literal["1", "1x1x1"] | None = None,
    search_radius: typing.Literal["3", "3x3x3"] | None = None,
    intensity_difference_sigma: float | None = 1.0,
    patch_similarity_sigma: float | None = 1.0,
    scale_levels: str | None = "32x16x8x2x1",
    interpolation: typing.Literal["Linear", "NearestNeighbor", "Gaussian", "BSpline", "CosineWindowedSinc", "WelchWindowedSinc", "HammingWindowedSinc", "LanczosWindowedSinc"] | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> NonLocalSuperResolutionOutputs:
    """
    Non-local super resolution described in the papers by JV Manjon et al., focusing
    on MRI superresolution using self-similarity and image priors.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_image: A low-resolution input image to be superresoluted.
        output: The output consists of the noise corrected version of the input\
            image. Optionally, one can also output the estimated noise image.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        interpolated_image: An interpolated version of the low-resolution image\
            (such as B-spline). Specify either this option or a high-resolution\
            multi-modal counterpart (cf the -k option).
        reference_image: A high-resolution reference multi-modal image. Assumed\
            to be in the same space as the low-resolution input image. Specify\
            either this option or an interpolated version (cf the -j option).
        patch_radius: Patch radius. Default = 1x1x1.
        search_radius: Search radius. Default = 3x3x3.
        intensity_difference_sigma: Intensity difference sigma. Default = 1.0.
        patch_similarity_sigma: Patch similarity sigma. Default = 1.0.
        scale_levels: Scale levels. Default = 32x16x8x2x1.
        interpolation: Several interpolation options are available in ITK.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NonLocalSuperResolutionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NON_LOCAL_SUPER_RESOLUTION_METADATA)
    cargs = []
    cargs.append("NonLocalSuperResolution")
    if image_dimensionality is not None:
        cargs.extend([
            "-d",
            str(image_dimensionality)
        ])
    cargs.extend([
        "-i",
        execution.input_file(input_image)
    ])
    if interpolated_image is not None:
        cargs.extend([
            "-j",
            execution.input_file(interpolated_image)
        ])
    if reference_image is not None:
        cargs.extend([
            "-k",
            execution.input_file(reference_image)
        ])
    if patch_radius is not None:
        cargs.extend([
            "-p",
            patch_radius
        ])
    if search_radius is not None:
        cargs.extend([
            "-r",
            search_radius
        ])
    if intensity_difference_sigma is not None:
        cargs.extend([
            "-g",
            str(intensity_difference_sigma)
        ])
    if patch_similarity_sigma is not None:
        cargs.extend([
            "-t",
            str(patch_similarity_sigma)
        ])
    if scale_levels is not None:
        cargs.extend([
            "-s",
            scale_levels
        ])
    if interpolation is not None:
        cargs.extend([
            "-n",
            interpolation
        ])
    cargs.extend([
        "-o",
        execution.input_file(output)
    ])
    if verbose is not None:
        cargs.extend([
            "-v",
            str(verbose)
        ])
    ret = NonLocalSuperResolutionOutputs(
        root=execution.output_file("."),
        superresoluted_output=execution.output_file(pathlib.Path(output).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NON_LOCAL_SUPER_RESOLUTION_METADATA",
    "NonLocalSuperResolutionOutputs",
    "non_local_super_resolution",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SUMA_MAKE_SPEC_SF_METADATA = Metadata(
    id="e84849d3eeb33bb18d791b3e555fb699941d3809.boutiques",
    name="@SUMA_Make_Spec_SF",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSumaMakeSpecSfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__suma_make_spec_sf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """All created files are stored in SURFACES directory"""


def v__suma_make_spec_sf(
    subject_id: str,
    debug_level: int | None = None,
    surface_path: str | None = None,
    runner: Runner | None = None,
) -> VSumaMakeSpecSfOutputs:
    """
    Prepare for surface viewing in SUMA.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        subject_id: Required subject ID for file naming.
        debug_level: Print debug information along the way.
        surface_path: Path to directory containing 'SURFACES' and AFNI volume\
            used in creating the surfaces.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSumaMakeSpecSfOutputs`).
    """
    if debug_level is not None and not (debug_level <= 2): 
        raise ValueError(f"'debug_level' must be less than x <= 2 but was {debug_level}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SUMA_MAKE_SPEC_SF_METADATA)
    cargs = []
    cargs.append("@SUMA_Make_Spec_SF")
    if debug_level is not None:
        cargs.extend([
            "-debug",
            str(debug_level)
        ])
    if surface_path is not None:
        cargs.extend([
            "-sfpath",
            surface_path
        ])
    cargs.extend([
        "-sid",
        subject_id
    ])
    ret = VSumaMakeSpecSfOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file("SURFACES/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSumaMakeSpecSfOutputs",
    "V__SUMA_MAKE_SPEC_SF_METADATA",
    "v__suma_make_spec_sf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REGISTER_CSH_METADATA = Metadata(
    id="8e13f3c3638f86e0bcc4bf3ee729a031f8071c67.boutiques",
    name="register.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RegisterCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `register_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_image: OutputPathType
    """The output registered image"""


def register_csh(
    base_image: InputPathType,
    new_image: InputPathType,
    options: str | None = None,
    runner: Runner | None = None,
) -> RegisterCshOutputs:
    """
    A script for registering MRI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        base_image: The base image for registration.
        new_image: The new image to be registered to the base image.
        options: Additional options for the register.csh command.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegisterCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REGISTER_CSH_METADATA)
    cargs = []
    cargs.append("register.csh")
    cargs.append(execution.input_file(base_image))
    cargs.append(execution.input_file(new_image))
    if options is not None:
        cargs.append(options)
    ret = RegisterCshOutputs(
        root=execution.output_file("."),
        registered_image=execution.output_file(pathlib.Path(new_image).name + "_registered"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REGISTER_CSH_METADATA",
    "RegisterCshOutputs",
    "register_csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPEC_FILE_MERGE_METADATA = Metadata(
    id="2c5e3a5c053998c2a574a6f035a5993430771a18.boutiques",
    name="spec-file-merge",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SpecFileMergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `spec_file_merge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def spec_file_merge(
    spec_1: str,
    spec_2: str,
    out_spec: str,
    runner: Runner | None = None,
) -> SpecFileMergeOutputs:
    """
    Merge two spec files into one.
    
    The output spec file contains every file that is in either of the input spec
    files.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        spec_1: first spec file to merge.
        spec_2: second spec file to merge.
        out_spec: output - output spec file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpecFileMergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPEC_FILE_MERGE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-spec-file-merge")
    cargs.append(spec_1)
    cargs.append(spec_2)
    cargs.append(out_spec)
    ret = SpecFileMergeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPEC_FILE_MERGE_METADATA",
    "SpecFileMergeOutputs",
    "spec_file_merge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMERGE_METADATA = Metadata(
    id="7f1c2ca1745d4893ae0eaf6d19b9cf828f0a6f25.boutiques",
    name="3dmerge",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmerge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output dataset file"""


def v_3dmerge(
    input_files: list[InputPathType],
    output_file: str,
    blur_fwhm: float | None = None,
    threshold: float | None = None,
    clust: list[float] | None = None,
    dindex: float | None = None,
    tindex: float | None = None,
    absolute: bool = False,
    dxyz: bool = False,
    gmean: bool = False,
    gmax: bool = False,
    quiet: bool = False,
    runner: Runner | None = None,
) -> V3dmergeOutputs:
    """
    3dmerge edits and merges 3D datasets by applying various operations like
    thresholding, blurring, clustering, and more.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input dataset files.
        output_file: Output dataset prefix.
        blur_fwhm: Gaussian blur with FWHM in mm.
        threshold: Threshold data to censor the intensities; only valid for\
            'fith', 'fico', or 'fitt' datasets.
        clust: Form clusters with connection distance and clip off data not in\
            clusters of a minimum volume.
        dindex: Specify sub-brick #j as the data source.
        tindex: Specify sub-brick #k as the threshold source.
        absolute: Take absolute values of intensities.
        dxyz: Force cluster editing to behave as if all voxel dimensions were\
            set to 1 mm.
        gmean: Combine datasets by averaging intensities (default).
        gmax: Combine datasets by taking max intensity.
        quiet: Reduce the number of messages shown.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMERGE_METADATA)
    cargs = []
    cargs.append("3dmerge")
    cargs.extend([execution.input_file(f) for f in input_files])
    cargs.extend([
        "-prefix",
        output_file
    ])
    if blur_fwhm is not None:
        cargs.extend([
            "-1blur_fwhm",
            str(blur_fwhm)
        ])
    if threshold is not None:
        cargs.extend([
            "-1thresh",
            str(threshold)
        ])
    if clust is not None:
        cargs.extend([
            "-1clust",
            *map(str, clust)
        ])
    if dindex is not None:
        cargs.extend([
            "-1dindex",
            str(dindex)
        ])
    if tindex is not None:
        cargs.extend([
            "-1tindex",
            str(tindex)
        ])
    if absolute:
        cargs.append("-1abs")
    if dxyz:
        cargs.append("-dxyz=1")
    if gmean:
        cargs.append("-gmean")
    if gmax:
        cargs.append("-gmax")
    if quiet:
        cargs.append("-quiet")
    ret = V3dmergeOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmergeOutputs",
    "V_3DMERGE_METADATA",
    "v_3dmerge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__CLUST_EXP_CAT_LAB_METADATA = Metadata(
    id="e3acc2b13b06a35c413b7c5aede3d8651316dbe3.boutiques",
    name="@ClustExp_CatLab",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VClustExpCatLabOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__clust_exp_cat_lab(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output data set concatenating labeled subbriks"""


def v__clust_exp_cat_lab(
    prefix: str,
    input_file: InputPathType,
    help_: bool = False,
    runner: Runner | None = None,
) -> VClustExpCatLabOutputs:
    """
    Helper script to concatenate and label a group of data sets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Output file name.
        input_file: Name of file containing the labels and data sets table\
            (e.g. subjects.csv).
        help_: Show help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VClustExpCatLabOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__CLUST_EXP_CAT_LAB_METADATA)
    cargs = []
    cargs.append("@ClustExp_CatLab")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    if help_:
        cargs.append("-help")
    ret = VClustExpCatLabOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VClustExpCatLabOutputs",
    "V__CLUST_EXP_CAT_LAB_METADATA",
    "v__clust_exp_cat_lab",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_SUBJECT_RH_METADATA = Metadata(
    id="f2d5e549617839220f590599e3a6e8f1eae8c024.boutiques",
    name="morph_subject-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphSubjectRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_subject_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_subject_rh(
    subject_id: str,
    runner: Runner | None = None,
) -> MorphSubjectRhOutputs:
    """
    A tool for morphing the right hemisphere of subject data in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject ID to morph the right hemisphere.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphSubjectRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_SUBJECT_RH_METADATA)
    cargs = []
    cargs.extend([
        "-rh",
        "morph_subject" + subject_id
    ])
    ret = MorphSubjectRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_SUBJECT_RH_METADATA",
    "MorphSubjectRhOutputs",
    "morph_subject_rh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TBSS_FILL_METADATA = Metadata(
    id="302dc5d0a540004a061db44ab4beabb876bbf335.boutiques",
    name="tbss_fill",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class TbssFillOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tbss_fill(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    filled_skeleton: OutputPathType
    """Filled skeletonized FA image"""


def tbss_fill(
    stats_image: InputPathType,
    threshold: float,
    mean_fa: InputPathType,
    output: str,
    include_negative_flag: bool = False,
    runner: Runner | None = None,
) -> TbssFillOutputs:
    """
    Tool for filling skeletonized FA images in TBSS.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        stats_image: Stats image.
        threshold: Threshold value.
        mean_fa: Mean FA image.
        output: Output image.
        include_negative_flag: Include negative stat values (below -threshold).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TbssFillOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TBSS_FILL_METADATA)
    cargs = []
    cargs.append("tbss_fill")
    cargs.append(execution.input_file(stats_image))
    cargs.append(str(threshold))
    cargs.append(execution.input_file(mean_fa))
    cargs.append(output)
    if include_negative_flag:
        cargs.append("-n")
    ret = TbssFillOutputs(
        root=execution.output_file("."),
        filled_skeleton=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TBSS_FILL_METADATA",
    "TbssFillOutputs",
    "tbss_fill",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_FIND_FLAT_REGIONS_METADATA = Metadata(
    id="5c7cb3d5470380e27f2e79106dbfa81d9cc3d3a9.boutiques",
    name="mris_find_flat_regions",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisFindFlatRegionsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_find_flat_regions(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label_file: OutputPathType
    """Output label file with regions where the surface is almost perpendicular
    to one of the cardinal axes"""


def mris_find_flat_regions(
    surface: InputPathType,
    wfile: str,
    threshold: float | None = 0.99,
    runner: Runner | None = None,
) -> MrisFindFlatRegionsOutputs:
    """
    Compute regions in which the surface is almost perpendicular to one of the
    cardinal axes and write the results to a label file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: Surface input file.
        wfile: Output label file.
        threshold: Threshold to use (default=0.990).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisFindFlatRegionsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_FIND_FLAT_REGIONS_METADATA)
    cargs = []
    cargs.append("mris_find_flat_regions")
    cargs.append(execution.input_file(surface))
    cargs.append(wfile)
    if threshold is not None:
        cargs.extend([
            "-t",
            str(threshold)
        ])
    ret = MrisFindFlatRegionsOutputs(
        root=execution.output_file("."),
        output_label_file=execution.output_file(wfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_FIND_FLAT_REGIONS_METADATA",
    "MrisFindFlatRegionsOutputs",
    "mris_find_flat_regions",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SEG_DIFF_METADATA = Metadata(
    id="71504722501dfa1ec92d8dd0c51d3ee7e1c9740c.boutiques",
    name="mri_seg_diff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSegDiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_seg_diff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    diff_output: OutputPathType
    """Output diff segmentation file."""
    merged_output: OutputPathType | None
    """Output merged segmentation file."""


def mri_seg_diff(
    diff: str,
    seg1: InputPathType | None = None,
    seg2: InputPathType | None = None,
    seg: InputPathType | None = None,
    merged: str | None = None,
    diff_force: bool = False,
    debug: bool = False,
    checkopts: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriSegDiffOutputs:
    """
    This program computes and merges differences in segmentation volumes, primarily
    for managing manual edits in FreeSurfer's aseg.mgz.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        diff: Output diff segmentation volume.
        seg1: First segmentation file (e.g., unedited).
        seg2: Second segmentation file (e.g., edited).
        seg: Source segmentation file (e.g., unedited).
        merged: Merged output, combining unedited with diff.
        diff_force: Force creation of a diff even if no diff is detected.
        debug: Turn on debugging.
        checkopts: Check options and exit without running.
        version: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSegDiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SEG_DIFF_METADATA)
    cargs = []
    cargs.append("mri_seg_diff")
    if seg1 is not None:
        cargs.extend([
            "--seg1",
            execution.input_file(seg1)
        ])
    if seg2 is not None:
        cargs.extend([
            "--seg2",
            execution.input_file(seg2)
        ])
    if seg is not None:
        cargs.extend([
            "--seg",
            execution.input_file(seg)
        ])
    cargs.extend([
        "--diff",
        diff
    ])
    if merged is not None:
        cargs.extend([
            "--merged",
            merged
        ])
    if diff_force:
        cargs.append("--diff-force")
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    if version:
        cargs.append("--version")
    ret = MriSegDiffOutputs(
        root=execution.output_file("."),
        diff_output=execution.output_file(diff),
        merged_output=execution.output_file(merged) if (merged is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SEG_DIFF_METADATA",
    "MriSegDiffOutputs",
    "mri_seg_diff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_PRETESS_METADATA = Metadata(
    id="4499558e540b531e057123dc0bdd2efbb168c515.boutiques",
    name="mri_pretess",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriPretessOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_pretess(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_newfilledvol: OutputPathType
    """Output new filled volume"""


def mri_pretess(
    filledvol: InputPathType,
    labelstring: str,
    normvol: InputPathType,
    newfilledvol: str,
    debug_voxel: list[float] | None = None,
    nocorners: bool = False,
    write: bool = False,
    keep: bool = False,
    test: bool = False,
    runner: Runner | None = None,
) -> MriPretessOutputs:
    """
    Tool to modify WM segmentation so that all neighbors of WM voxels have a common
    face.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        filledvol: Input filled volume, usually wm.mgz.
        labelstring: Label string, usually wm.
        normvol: Normalization volume, usually norm.mgz.
        newfilledvol: New filled volume output, usually wm.mgz.
        debug_voxel: Specify the voxel to debug with coordinates C R S.
        nocorners: No removal of corner configurations in addition to edge ones.
        write: Turn on diagnostic writing.
        keep: Keep WM edits.
        test: Adds a voxel to test removal by mri_pretess, retained with -keep.\
            Output not saved.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriPretessOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_PRETESS_METADATA)
    cargs = []
    cargs.append("mri_pretess")
    cargs.append(execution.input_file(filledvol))
    cargs.append(labelstring)
    cargs.append(execution.input_file(normvol))
    cargs.append(newfilledvol)
    if debug_voxel is not None:
        cargs.extend([
            "-debug_voxel",
            *map(str, debug_voxel)
        ])
    if nocorners:
        cargs.append("-nocorners")
    if write:
        cargs.append("-w")
    if keep:
        cargs.append("-keep")
    if test:
        cargs.append("-test")
    ret = MriPretessOutputs(
        root=execution.output_file("."),
        out_newfilledvol=execution.output_file(newfilledvol),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_PRETESS_METADATA",
    "MriPretessOutputs",
    "mri_pretess",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SH2PEAKS_METADATA = Metadata(
    id="dc59048f9a978e195396202a13dd54ccebc30173.boutiques",
    name="sh2peaks",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Sh2peaksDirection:
    """
    the direction of a peak to estimate. The algorithm will attempt to find the
    same number of peaks as have been specified using this option.
    """
    phi: float
    """the direction of a peak to estimate. The algorithm will attempt to find
    the same number of peaks as have been specified using this option."""
    theta: float
    """the direction of a peak to estimate. The algorithm will attempt to find
    the same number of peaks as have been specified using this option."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-direction")
        cargs.append(str(self.phi))
        cargs.append(str(self.theta))
        return cargs


@dataclasses.dataclass
class Sh2peaksConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Sh2peaksOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sh2peaks(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output image. Each volume corresponds to the x, y & z component of
    each peak direction vector in turn."""


def sh2peaks(
    sh: InputPathType,
    output: str,
    num: int | None = None,
    direction: list[Sh2peaksDirection] | None = None,
    peaks: InputPathType | None = None,
    threshold: float | None = None,
    seeds: InputPathType | None = None,
    mask: InputPathType | None = None,
    fast: bool = False,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Sh2peaksConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Sh2peaksOutputs:
    """
    Extract the peaks of a spherical harmonic function in each voxel.
    
    Peaks of the spherical harmonic function in each voxel are located by
    commencing a Newton search along each of a set of pre-specified directions
    
    The spherical harmonic coefficients are stored according the conventions
    described the main documentation, which can be found at the following link:
    https://mrtrix.readthedocs.io/en/3.0.4/concepts/spherical_harmonics.html
    
    References:
    
    Jeurissen, B.; Leemans, A.; Tournier, J.-D.; Jones, D.K.; Sijbers, J.
    Investigating the prevalence of complex fiber configurations in white matter
    tissue with diffusion magnetic resonance imaging. Human Brain Mapping, 2013,
    34(11), 2747-2766.
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        sh: the input image of SH coefficients.
        output: the output image. Each volume corresponds to the x, y & z\
            component of each peak direction vector in turn.
        num: the number of peaks to extract (default: 3).
        direction: the direction of a peak to estimate. The algorithm will\
            attempt to find the same number of peaks as have been specified using\
            this option.
        peaks: the program will try to find the peaks that most closely match\
            those in the image provided.
        threshold: only peak amplitudes greater than the threshold will be\
            considered.
        seeds: specify a set of directions from which to start the multiple\
            restarts of the optimisation (by default, the built-in 60 direction set\
            is used).
        mask: only perform computation within the specified binary brain mask\
            image.
        fast: use lookup table to compute associated Legendre polynomials\
            (faster, but approximate).
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Sh2peaksOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SH2PEAKS_METADATA)
    cargs = []
    cargs.append("sh2peaks")
    if num is not None:
        cargs.extend([
            "-num",
            str(num)
        ])
    if direction is not None:
        cargs.extend([a for c in [s.run(execution) for s in direction] for a in c])
    if peaks is not None:
        cargs.extend([
            "-peaks",
            execution.input_file(peaks)
        ])
    if threshold is not None:
        cargs.extend([
            "-threshold",
            str(threshold)
        ])
    if seeds is not None:
        cargs.extend([
            "-seeds",
            execution.input_file(seeds)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if fast:
        cargs.append("-fast")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(sh))
    cargs.append(output)
    ret = Sh2peaksOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SH2PEAKS_METADATA",
    "Sh2peaksConfig",
    "Sh2peaksDirection",
    "Sh2peaksOutputs",
    "sh2peaks",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIND_THE_BIGGEST_METADATA = Metadata(
    id="3dbb5859444668bef5d4d2dc4f26feb48bfc1655.boutiques",
    name="find_the_biggest",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FindTheBiggestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `find_the_biggest(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Index of the largest volume or surface"""


def find_the_biggest(
    volumes_surfaces: list[InputPathType],
    output_index: str,
    runner: Runner | None = None,
) -> FindTheBiggestOutputs:
    """
    Tool to find the largest volume or surface from a set of inputs.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        volumes_surfaces: List of input volumes or surfaces.
        output_index: Output index of the largest volume or surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FindTheBiggestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIND_THE_BIGGEST_METADATA)
    cargs = []
    cargs.append("find_the_biggest")
    cargs.extend([execution.input_file(f) for f in volumes_surfaces])
    cargs.append(output_index)
    ret = FindTheBiggestOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_index),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIND_THE_BIGGEST_METADATA",
    "FindTheBiggestOutputs",
    "find_the_biggest",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_RESTRICT_DENSE_MAP_METADATA = Metadata(
    id="b24c61221e5bb2198d65942d58627263daee752d.boutiques",
    name="cifti-restrict-dense-map",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class CiftiRestrictDenseMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_restrict_dense_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""


def cifti_restrict_dense_map(
    cifti_in: InputPathType,
    direction: str,
    cifti_out: str,
    opt_cifti_roi_roi_cifti: InputPathType | None = None,
    opt_left_roi_roi_metric: InputPathType | None = None,
    opt_right_roi_roi_metric: InputPathType | None = None,
    opt_cerebellum_roi_roi_metric: InputPathType | None = None,
    opt_vol_roi_roi_vol: InputPathType | None = None,
    runner: Runner | None = None,
) -> CiftiRestrictDenseMapOutputs:
    """
    Exclude brainordinates from a cifti file.
    
    Writes a modified version of <cifti-in>, where all brainordinates outside
    the specified roi(s) are removed from the file. The direction can be either
    an integer starting from 1, or the strings 'ROW' or 'COLUMN'. If -cifti-roi
    is specified, no other -*-roi option may be specified. If not using
    -cifti-roi, any -*-roi options not present will discard the relevant
    structure, if present in the input file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input cifti.
        direction: which dimension to change the mapping on (integer, 'ROW', or\
            'COLUMN').
        cifti_out: the output cifti.
        opt_cifti_roi_roi_cifti: cifti file containing combined rois: the rois\
            as a cifti file.
        opt_left_roi_roi_metric: vertices to use from left hemisphere: the left\
            roi as a metric file.
        opt_right_roi_roi_metric: vertices to use from right hemisphere: the\
            right roi as a metric file.
        opt_cerebellum_roi_roi_metric: vertices to use from cerebellum: the\
            cerebellum roi as a metric file.
        opt_vol_roi_roi_vol: voxels to use: the roi volume file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiRestrictDenseMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_RESTRICT_DENSE_MAP_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-restrict-dense-map")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(direction)
    cargs.append(cifti_out)
    if opt_cifti_roi_roi_cifti is not None:
        cargs.extend([
            "-cifti-roi",
            execution.input_file(opt_cifti_roi_roi_cifti)
        ])
    if opt_left_roi_roi_metric is not None:
        cargs.extend([
            "-left-roi",
            execution.input_file(opt_left_roi_roi_metric)
        ])
    if opt_right_roi_roi_metric is not None:
        cargs.extend([
            "-right-roi",
            execution.input_file(opt_right_roi_roi_metric)
        ])
    if opt_cerebellum_roi_roi_metric is not None:
        cargs.extend([
            "-cerebellum-roi",
            execution.input_file(opt_cerebellum_roi_roi_metric)
        ])
    if opt_vol_roi_roi_vol is not None:
        cargs.extend([
            "-vol-roi",
            execution.input_file(opt_vol_roi_roi_vol)
        ])
    ret = CiftiRestrictDenseMapOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_RESTRICT_DENSE_MAP_METADATA",
    "CiftiRestrictDenseMapOutputs",
    "cifti_restrict_dense_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_LABEL_IMPORT_METADATA = Metadata(
    id="dde3112ce19a06b1bb86a1f6f785ca6b9271992e.boutiques",
    name="volume-label-import",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeLabelImportOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_label_import(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output workbench label volume"""


def volume_label_import(
    input_: InputPathType,
    label_list_file: str,
    output: str,
    opt_discard_others: bool = False,
    opt_unlabeled_value_value: int | None = None,
    opt_subvolume_subvol: str | None = None,
    opt_drop_unused_labels: bool = False,
    runner: Runner | None = None,
) -> VolumeLabelImportOutputs:
    """
    Import a label volume to workbench format.
    
    Creates a label volume from an integer-valued volume file. The label name
    and color information is stored in the volume header in a nifti extension,
    with a similar format as in caret5, see -volume-help. You may specify the
    empty string (use "") for <label-list-file>, which will be treated as if it
    is an empty file. The label list file must have the following format (2
    lines per label):
    
    <labelname>
    <key> <red> <green> <blue> <alpha>
    ...
    
    Label names are specified on a separate line from their value and color, in
    order to let label names contain spaces. Whitespace is trimmed from both
    ends of the label name, but is kept if it is in the middle of a label. Do
    not specify the "unlabeled" key in the file, it is assumed that 0 means not
    labeled unless -unlabeled-value is specified. The value of <key> specifies
    what value in the imported file should be used as this label (these same key
    values are also used in the output file). The values of <red>, <green>,
    <blue> and <alpha> must be integers from 0 to 255, and will specify the
    color the label is drawn as (alpha of 255 means fully opaque, which is
    probably what you want).
    
    By default, it will create new label names with names like LABEL_5 for any
    values encountered that are not mentioned in the list file, specify
    -discard-others to instead set these values to the "unlabeled" key.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        input_: the input volume file.
        label_list_file: text file containing the values and names for labels.
        output: the output workbench label volume.
        opt_discard_others: set any voxels with values not mentioned in the\
            label list to the ??? label.
        opt_unlabeled_value_value: set the value that will be interpreted as\
            unlabeled: the numeric value for unlabeled (default 0).
        opt_subvolume_subvol: select a single subvolume to import: the\
            subvolume number or name.
        opt_drop_unused_labels: remove any unused label values from the label\
            table.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeLabelImportOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_LABEL_IMPORT_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-label-import")
    cargs.append(execution.input_file(input_))
    cargs.append(label_list_file)
    cargs.append(output)
    if opt_discard_others:
        cargs.append("-discard-others")
    if opt_unlabeled_value_value is not None:
        cargs.extend([
            "-unlabeled-value",
            str(opt_unlabeled_value_value)
        ])
    if opt_subvolume_subvol is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvol
        ])
    if opt_drop_unused_labels:
        cargs.append("-drop-unused-labels")
    ret = VolumeLabelImportOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_LABEL_IMPORT_METADATA",
    "VolumeLabelImportOutputs",
    "volume_label_import",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_RGB_RH_METADATA = Metadata(
    id="d9ff451dc5d9779a26edbf9b5422cc9aac7df58e.boutiques",
    name="morph_rgb-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphRgbRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_rgb_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_rgb_rh(
    subject_id: str,
    runner: Runner | None = None,
) -> MorphRgbRhOutputs:
    """
    Morphs RGB values onto a FreeSurfer right hemisphere surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject ID for which the RGB morphing should be performed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphRgbRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_RGB_RH_METADATA)
    cargs = []
    cargs.extend([
        "-rh",
        "morph_rgb" + subject_id
    ])
    ret = MorphRgbRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_RGB_RH_METADATA",
    "MorphRgbRhOutputs",
    "morph_rgb_rh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_PROFILE_CLUSTERING_METADATA = Metadata(
    id="1c62a3900080cd0e8bb349d786478f4b3b3ddb1d.boutiques",
    name="mris_profileClustering",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisProfileClusteringOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_profile_clustering(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    clustering_output: OutputPathType
    """File with the clustering results."""


def mris_profile_clustering(
    input_file: InputPathType,
    output_file: str,
    other_options: str | None = None,
    runner: Runner | None = None,
) -> MrisProfileClusteringOutputs:
    """
    A tool from Freesurfer for clustering based on profile data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file required for clustering.
        output_file: Output file to store clustering results.
        other_options: Other various options for tuning the clustering process.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisProfileClusteringOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_PROFILE_CLUSTERING_METADATA)
    cargs = []
    cargs.append("mris_profileClustering")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    if other_options is not None:
        cargs.append(other_options)
    ret = MrisProfileClusteringOutputs(
        root=execution.output_file("."),
        clustering_output=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_PROFILE_CLUSTERING_METADATA",
    "MrisProfileClusteringOutputs",
    "mris_profile_clustering",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_PATH2LABEL_METADATA = Metadata(
    id="ac055539c26e5fa7d5b552e4523192ffbd1a7979.boutiques",
    name="mri_path2label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriPath2labelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_path2label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_path2label(
    input_file: str,
    output_file: str,
    single: bool = False,
    path_to_label: bool = False,
    label_to_path: bool = False,
    connect: list[str] | None = None,
    fill: list[str] | None = None,
    confillx: list[str] | None = None,
    confill: list[str] | None = None,
    source_file: str | None = None,
    dest_file: str | None = None,
    runner: Runner | None = None,
) -> MriPath2labelOutputs:
    """
    Converts a path file to a label or a label file to a path file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file, either a path or label file.
        output_file: Output file, either a path or label file.
        single: Only convert a single path, and do not use sentinel values.
        path_to_label: Treat input as a path and output a label.
        label_to_path: Treat input as a label and output a path.
        connect: Connect path; input and output must be paths; requires subject\
            and hemi.
        fill: Fill already closed, connected path; input must be a path, output\
            must be a label; requires subject, hemi, and seedvtx.
        confillx: Connect and fill path; input must be a path, output must be a\
            label; requires surface_fname and seedvtx.
        confill: Connect and fill path; input must be a path, output must be a\
            label; requires subject, hemi, and seedvtx.
        source_file: The path file, if path2label.
        dest_file: The label file, if path2label.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriPath2labelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_PATH2LABEL_METADATA)
    cargs = []
    cargs.append("mri_path2label")
    cargs.append(input_file)
    cargs.append(output_file)
    if single:
        cargs.append("--single")
    if path_to_label:
        cargs.append("--path2label")
    if label_to_path:
        cargs.append("--label2path")
    if connect is not None:
        cargs.extend([
            "--connect",
            *connect
        ])
    if fill is not None:
        cargs.extend([
            "--fill",
            *fill
        ])
    if confillx is not None:
        cargs.extend([
            "--confillx",
            *confillx
        ])
    if confill is not None:
        cargs.extend([
            "--confill",
            *confill
        ])
    if source_file is not None:
        cargs.extend([
            "--i",
            source_file
        ])
    if dest_file is not None:
        cargs.extend([
            "--o",
            dest_file
        ])
    ret = MriPath2labelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_PATH2LABEL_METADATA",
    "MriPath2labelOutputs",
    "mri_path2label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_BANDPASS_METADATA = Metadata(
    id="69b4e08ff33a85a01f56df929195839c7c7f9208.boutiques",
    name="1dBandpass",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dBandpassOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_bandpass(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_1d_bandpass(
    fbot: float,
    ftop: float,
    infile: InputPathType,
    timestep: float | None = None,
    ortfile: InputPathType | None = None,
    nodetrend: bool = False,
    norm: bool = False,
    runner: Runner | None = None,
) -> V1dBandpassOutputs:
    """
    Bandpass filtering of time series data in AFNI *.1D files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        fbot: Lowest frequency in the passband, in Hz (must be greater than or\
            equal to 0).
        ftop: Highest frequency in the passband, in Hz (must be greater than\
            FBOT).
        infile: Input AFNI *.1D file; each column is processed.
        timestep: Set time step to 'dd' sec (default is 1.0).
        ortfile: Also orthogonalize input to columns in specified *.1D file\
            (only one '-ort' option is allowed).
        nodetrend: Skip the quadratic detrending of the input.
        norm: Make output time series have L2 norm = 1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dBandpassOutputs`).
    """
    if not (0 <= fbot): 
        raise ValueError(f"'fbot' must be greater than 0 <= x but was {fbot}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_BANDPASS_METADATA)
    cargs = []
    cargs.append("1dBandpass")
    cargs.append(str(fbot))
    cargs.append(str(ftop))
    cargs.append(execution.input_file(infile))
    if timestep is not None:
        cargs.extend([
            "-dt",
            str(timestep)
        ])
    if ortfile is not None:
        cargs.extend([
            "-ort",
            execution.input_file(ortfile)
        ])
    if nodetrend:
        cargs.append("-nodetrend")
    if norm:
        cargs.append("-norm")
    ret = V1dBandpassOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dBandpassOutputs",
    "V_1D_BANDPASS_METADATA",
    "v_1d_bandpass",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_INFLATE_METADATA = Metadata(
    id="43f3d6dc1b42aaf5d8e8b357955f64c384b5d241.boutiques",
    name="mris_inflate",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisInflateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_inflate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface_file: OutputPathType
    """Output surface file"""


def mris_inflate(
    input_surface: InputPathType,
    output_surface: str,
    max_iterations: float | None = None,
    snapshot_interval: float | None = None,
    dist_coefficient: float | None = None,
    no_save_sulc: bool = False,
    sulcname: str | None = None,
    mm_flag: bool = False,
    scale_flag: float | None = None,
    runner: Runner | None = None,
) -> MrisInflateOutputs:
    """
    Cortical surface inflation tool.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        output_surface: Output surface file.
        max_iterations: Set the maximum number of iterations (default: 10).
        snapshot_interval: Write out a snapshot of the inflation every\
            specified time step.
        dist_coefficient: Specify the relative strength of the metric\
            preserving term in the cost functional versus the smoothing term\
            (default: 0.1).
        no_save_sulc: Do not save ?h.sulc.
        sulcname: Save to ?h.sulcname.
        mm_flag: Compute sulc in mm without zero meaning or scaling.
        scale_flag: Disable or enable scaling of inflated brain.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisInflateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_INFLATE_METADATA)
    cargs = []
    cargs.append("mris_inflate")
    cargs.append(execution.input_file(input_surface))
    cargs.append(output_surface)
    if max_iterations is not None:
        cargs.extend([
            "-n",
            str(max_iterations)
        ])
    if snapshot_interval is not None:
        cargs.extend([
            "-w",
            str(snapshot_interval)
        ])
    if dist_coefficient is not None:
        cargs.extend([
            "-dist",
            str(dist_coefficient)
        ])
    if no_save_sulc:
        cargs.append("-no-save-sulc")
    if sulcname is not None:
        cargs.extend([
            "-sulc",
            sulcname
        ])
    if mm_flag:
        cargs.append("-mm")
    if scale_flag is not None:
        cargs.extend([
            "-scale",
            str(scale_flag)
        ])
    ret = MrisInflateOutputs(
        root=execution.output_file("."),
        output_surface_file=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_INFLATE_METADATA",
    "MrisInflateOutputs",
    "mris_inflate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PERFUSION_SUBTRACT_METADATA = Metadata(
    id="8a0b5c252cd2198e9f3ba22398f35e5e42e86246.boutiques",
    name="perfusion_subtract",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class PerfusionSubtractOutputs(typing.NamedTuple):
    """
    Output object returned when calling `perfusion_subtract(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output 4D image with subtraction results"""


def perfusion_subtract(
    four_d_input: InputPathType,
    four_d_output: str,
    control_first_flag: bool = False,
    runner: Runner | None = None,
) -> PerfusionSubtractOutputs:
    """
    Subtract control images from tag images in 4D perfusion data.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        four_d_input: Input 4D perfusion image (e.g. perfusion.nii.gz).
        four_d_output: Output 4D image with subtraction results (e.g.\
            perfusion_subtracted.nii.gz).
        control_first_flag: First timepoint is control instead of tag. Default\
            is tag first.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PerfusionSubtractOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PERFUSION_SUBTRACT_METADATA)
    cargs = []
    cargs.append("perfusion_subtract")
    cargs.append(execution.input_file(four_d_input))
    cargs.append(four_d_output)
    if control_first_flag:
        cargs.append("-c")
    ret = PerfusionSubtractOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(four_d_output + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PERFUSION_SUBTRACT_METADATA",
    "PerfusionSubtractOutputs",
    "perfusion_subtract",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_SPLINE_METADATA = Metadata(
    id="4353558de4079bf74ac843d967ea19386bdf663f.boutiques",
    name="dmri_spline",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriSplineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_spline(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_volume: OutputPathType | None
    """Output volume of the interpolated spline"""
    out_points_file: OutputPathType | None
    """Output text file with interpolated spline points"""
    out_tangent_vectors: OutputPathType | None
    """Output text file containing tangent vectors"""
    out_normal_vectors: OutputPathType | None
    """Output text file containing normal vectors"""
    out_curvature: OutputPathType | None
    """Output text file containing curvatures"""


def dmri_spline(
    control_points_file: InputPathType,
    mask_volume: InputPathType,
    output_volume: InputPathType | None = None,
    show_points: bool = False,
    output_points: InputPathType | None = None,
    output_vectors_base: str | None = None,
    debug: bool = False,
    check_options: bool = False,
    runner: Runner | None = None,
) -> DmriSplineOutputs:
    """
    Tool for interpolating and analyzing splines within a defined mask.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        control_points_file: Input text file containing control points.
        mask_volume: Input mask volume (spline is not allowed to stray off\
            mask).
        output_volume: Output volume of the interpolated spline.
        show_points: Highlight control points in output volume (default: no).
        output_points: Output text file containing all interpolated spline\
            points.
        output_vectors_base: Base name of output text files containing tangent\
            vectors, normal vectors, and curvatures at every point along the spline.
        debug: Turn on debugging.
        check_options: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriSplineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_SPLINE_METADATA)
    cargs = []
    cargs.append("dmri_spline")
    cargs.extend([
        "--cpts",
        execution.input_file(control_points_file)
    ])
    cargs.extend([
        "--mask",
        execution.input_file(mask_volume)
    ])
    if output_volume is not None:
        cargs.extend([
            "--out",
            execution.input_file(output_volume)
        ])
    if show_points:
        cargs.append("--show")
    if output_points is not None:
        cargs.extend([
            "--outpts",
            execution.input_file(output_points)
        ])
    if output_vectors_base is not None:
        cargs.extend([
            "--outvec",
            output_vectors_base
        ])
    if debug:
        cargs.append("--debug")
    if check_options:
        cargs.append("--checkopts")
    ret = DmriSplineOutputs(
        root=execution.output_file("."),
        out_volume=execution.output_file(pathlib.Path(output_volume).name) if (output_volume is not None) else None,
        out_points_file=execution.output_file(pathlib.Path(output_points).name) if (output_points is not None) else None,
        out_tangent_vectors=execution.output_file(output_vectors_base + "_tangent.txt") if (output_vectors_base is not None) else None,
        out_normal_vectors=execution.output_file(output_vectors_base + "_normal.txt") if (output_vectors_base is not None) else None,
        out_curvature=execution.output_file(output_vectors_base + "_curvature.txt") if (output_vectors_base is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_SPLINE_METADATA",
    "DmriSplineOutputs",
    "dmri_spline",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_LIB_CHECK_METADATA = Metadata(
    id="f37fc790fdaf3a4bfa36c3a6d4c66c5bcc752a3c.boutiques",
    name="fs_lib_check",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsLibCheckOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_lib_check(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fs_lib_check(
    use_ldconfig: bool = False,
    use_rpm: bool = False,
    show_help: bool = False,
    show_version: bool = False,
    runner: Runner | None = None,
) -> FsLibCheckOutputs:
    """
    Checks if the operating system has the necessary system libraries required to
    run FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        use_ldconfig: Force use of 'ldconfig' to check for instances of\
            required system libraries. This is useful on rpm systems if system\
            libraries were installed from source code, and are thus not known to\
            the system rpm database.
        use_rpm: Force use of 'rpm -qa' to check for installed library\
            packages. If -r and -l are both specified concurrently, then behavior\
            is unspecified.
        show_help: Show this synopsis and exit.
        show_version: Show a version number and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsLibCheckOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_LIB_CHECK_METADATA)
    cargs = []
    cargs.append("fs_lib_check")
    if use_ldconfig:
        cargs.append("-l")
    if use_rpm:
        cargs.append("-r")
    if show_help:
        cargs.append("-h")
    if show_version:
        cargs.append("-v")
    ret = FsLibCheckOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_LIB_CHECK_METADATA",
    "FsLibCheckOutputs",
    "fs_lib_check",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_REGISTER_TO_VOLUME_METADATA = Metadata(
    id="9bdc925a77ef7d3c8dc9cd1fecb43c21110eb66b.boutiques",
    name="mris_register_to_volume",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRegisterToVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_register_to_volume(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_register_to_volume(
    surface: str,
    pial: str,
    reg: str,
    mri_reg: str,
    pial_only: str | None = None,
    noglobal: bool = False,
    median: bool = False,
    tx_mmd: list[float] | None = None,
    ty_mmd: list[float] | None = None,
    tz_mmd: list[float] | None = None,
    ax_mmd: list[float] | None = None,
    ay_mmd: list[float] | None = None,
    az_mmd: list[float] | None = None,
    cost: str | None = None,
    interp: str | None = None,
    noise: float | None = None,
    seed: float | None = None,
    skip: list[float] | None = None,
    sigma: list[float] | None = None,
    cnr: bool = False,
    max_rot: float | None = None,
    max_trans: float | None = None,
    border: float | None = None,
    subject: str | None = None,
    dilate: float | None = None,
    patch: str | None = None,
    label: str | None = None,
    out_reg: str | None = None,
    runner: Runner | None = None,
) -> MrisRegisterToVolumeOutputs:
    """
    Aligns cortical surfaces to a volumetric template.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: The main surface file.
        pial: Pial surface name.
        reg: Registration file.
        mri_reg: MRI volume registration file.
        pial_only: Pial surface name (only).
        noglobal: Do not use global optimization.
        median: Use median filtering.
        tx_mmd: Translation in x (min, max, delta).
        ty_mmd: Translation in y (min, max, delta).
        tz_mmd: Translation in z (min, max, delta).
        ax_mmd: Rotation about x (min, max, delta).
        ay_mmd: Rotation about y (min, max, delta).
        az_mmd: Rotation about z (min, max, delta).
        cost: Cost file.
        interp: Interpolation type: trilinear or nearest.
        noise: Add noise with stddev for testing sensitivity.
        seed: Random seed for use with noise.
        skip: Number of vertices to skip.
        sigma: Size of blurring kernels to use.
        cnr: Use CNR-based similarity function.
        max_rot: Max angle (degrees) to search over.
        max_trans: Max translation (mm) to search over.
        border: Size of the border region to ignore.
        subject: Specify name of subject (for register.dat file).
        dilate: Dilate ripflags ndil times.
        patch: Load patch and limit calculations.
        label: Load label and limit calculations.
        out_reg: Output registration at lowest cost.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRegisterToVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_REGISTER_TO_VOLUME_METADATA)
    cargs = []
    cargs.append("mris_register_to_volume")
    cargs.extend([
        "--surf",
        surface
    ])
    cargs.extend([
        "--pial",
        pial
    ])
    if pial_only is not None:
        cargs.extend([
            "--pial_only",
            pial_only
        ])
    cargs.extend([
        "--reg",
        reg
    ])
    if noglobal:
        cargs.append("--noglobal")
    if median:
        cargs.append("--median")
    cargs.extend([
        "--mri_reg",
        mri_reg
    ])
    if tx_mmd is not None:
        cargs.extend([
            "--tx-mmd",
            *map(str, tx_mmd)
        ])
    if ty_mmd is not None:
        cargs.extend([
            "--ty-mmd",
            *map(str, ty_mmd)
        ])
    if tz_mmd is not None:
        cargs.extend([
            "--tz-mmd",
            *map(str, tz_mmd)
        ])
    if ax_mmd is not None:
        cargs.extend([
            "--ax-mmd",
            *map(str, ax_mmd)
        ])
    if ay_mmd is not None:
        cargs.extend([
            "--ay-mmd",
            *map(str, ay_mmd)
        ])
    if az_mmd is not None:
        cargs.extend([
            "--az-mmd",
            *map(str, az_mmd)
        ])
    if cost is not None:
        cargs.extend([
            "--cost",
            cost
        ])
    if interp is not None:
        cargs.extend([
            "--interp",
            interp
        ])
    if noise is not None:
        cargs.extend([
            "--noise",
            str(noise)
        ])
    if seed is not None:
        cargs.extend([
            "--seed",
            str(seed)
        ])
    if skip is not None:
        cargs.extend([
            "--skip",
            *map(str, skip)
        ])
    if sigma is not None:
        cargs.extend([
            "--sigma",
            *map(str, sigma)
        ])
    if cnr:
        cargs.append("--CNR")
    if max_rot is not None:
        cargs.extend([
            "--max_rot",
            str(max_rot)
        ])
    if max_trans is not None:
        cargs.extend([
            "--max_trans",
            str(max_trans)
        ])
    if border is not None:
        cargs.extend([
            "--border",
            str(border)
        ])
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if dilate is not None:
        cargs.extend([
            "--dilate",
            str(dilate)
        ])
    if patch is not None:
        cargs.extend([
            "--patch",
            patch
        ])
    if label is not None:
        cargs.extend([
            "--label",
            label
        ])
    if out_reg is not None:
        cargs.extend([
            "--out-reg",
            out_reg
        ])
    ret = MrisRegisterToVolumeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_REGISTER_TO_VOLUME_METADATA",
    "MrisRegisterToVolumeOutputs",
    "mris_register_to_volume",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BORDER_TO_VERTICES_METADATA = Metadata(
    id="e79a75a02c66aa23aaa2fd35713b5557b9d4e7e5.boutiques",
    name="border-to-vertices",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class BorderToVerticesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `border_to_vertices(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def border_to_vertices(
    surface: InputPathType,
    border_file: InputPathType,
    metric_out: str,
    opt_border_name: str | None = None,
    runner: Runner | None = None,
) -> BorderToVerticesOutputs:
    """
    Draw borders as vertices in a metric file.
    
    Outputs a metric with 1s on vertices that follow a border, and 0s elsewhere.
    By default, a separate metric column is created for each border.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface the borders are drawn on.
        border_file: the border file.
        metric_out: the output metric file.
        opt_border_name: create ROI for only one border: the name of the border.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderToVerticesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_TO_VERTICES_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-to-vertices")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(border_file))
    cargs.append(metric_out)
    if opt_border_name is not None:
        cargs.extend([
            "-border",
            opt_border_name
        ])
    ret = BorderToVerticesOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BORDER_TO_VERTICES_METADATA",
    "BorderToVerticesOutputs",
    "border_to_vertices",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_NEW_RH_METADATA = Metadata(
    id="6ededf15eee0d58308af964a359eb602b1b300a0.boutiques",
    name="inflate_subject_new-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectNewRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_new_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def inflate_subject_new_rh(
    args: str | None = None,
    runner: Runner | None = None,
) -> InflateSubjectNewRhOutputs:
    """
    This is a placeholder descriptor for the 'inflate_subject_new-rh' command. The
    tool appears to be part of FreeSurfer but the specific inputs, outputs or
    options couldn't be extracted from the help text.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        args: Additional command-line arguments for inflate_subject_new-rh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectNewRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_NEW_RH_METADATA)
    cargs = []
    if args is not None:
        cargs.extend([
            "-rh",
            "inflate_subject_new" + args
        ])
    ret = InflateSubjectNewRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_NEW_RH_METADATA",
    "InflateSubjectNewRhOutputs",
    "inflate_subject_new_rh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_LANDMARK_BASED_TRANSFORM_INITIALIZER_METADATA = Metadata(
    id="e680d25c4b1661ea27d0968828f088b5d76779fa.boutiques",
    name="antsLandmarkBasedTransformInitializer",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsLandmarkBasedTransformInitializerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_landmark_based_transform_initializer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform: OutputPathType
    """The output file containing the initialized transform."""


def ants_landmark_based_transform_initializer(
    dimension: int,
    fixed_image: InputPathType,
    moving_image: InputPathType,
    transform_type: typing.Literal["rigid", "affine", "bspline"],
    output_transform: InputPathType,
    mesh_size: str | None = None,
    number_of_levels: int | None = None,
    order: int | None = None,
    enforce_stationary_boundaries: typing.Literal[0, 1] | None = None,
    landmark_weights: InputPathType | None = None,
    runner: Runner | None = None,
) -> AntsLandmarkBasedTransformInitializerOutputs:
    """
    This tool initializes a transform between two images based on corresponding
    landmarks.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimension: The dimensionality of the registration problem (e.g., 2 for\
            2D, 3 for 3D).
        fixed_image: The fixed image in the registration process.
        moving_image: The moving image in the registration process.
        transform_type: The type of transform to initialize. Options are\
            'rigid', 'affine', or 'bspline'.
        output_transform: The output transform file that will be created.
        mesh_size: The mesh size for the B-spline transform, specified as\
            'meshSize[0]xmeshSize[1]x...'. Default is '1x1x1'.
        number_of_levels: Number of levels for multi-resolution fitting.\
            Default is 4.
        order: The polynomial order of the B-spline transform. Default is 3.
        enforce_stationary_boundaries: Enforces stationary boundaries for the\
            B-spline transform. Default is 1 (true).
        landmark_weights: File containing landmark weights. Each row is either\
            'label,labelWeight' or 'labelWeight'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsLandmarkBasedTransformInitializerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_LANDMARK_BASED_TRANSFORM_INITIALIZER_METADATA)
    cargs = []
    cargs.append("antsLandmarkBasedTransformInitializer")
    cargs.append(str(dimension))
    cargs.append(execution.input_file(fixed_image))
    cargs.append(execution.input_file(moving_image))
    cargs.append(transform_type)
    cargs.append(execution.input_file(output_transform))
    if mesh_size is not None:
        cargs.append(mesh_size)
    if number_of_levels is not None:
        cargs.append(str(number_of_levels))
    if order is not None:
        cargs.append(str(order))
    if enforce_stationary_boundaries is not None:
        cargs.append(str(enforce_stationary_boundaries))
    if landmark_weights is not None:
        cargs.append(execution.input_file(landmark_weights))
    ret = AntsLandmarkBasedTransformInitializerOutputs(
        root=execution.output_file("."),
        output_transform=execution.output_file(pathlib.Path(output_transform).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_LANDMARK_BASED_TRANSFORM_INITIALIZER_METADATA",
    "AntsLandmarkBasedTransformInitializerOutputs",
    "ants_landmark_based_transform_initializer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TALAIRACH_METADATA = Metadata(
    id="1512333dd2617cccb8f9ea33a7bc7b56b8c724e3.boutiques",
    name="talairach",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TalairachOutputs(typing.NamedTuple):
    """
    Output object returned when calling `talairach(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    xfm_output: OutputPathType
    """Output transformation file."""


def talairach(
    input_volume: InputPathType,
    output_transform: str,
    log_flag: bool = False,
    debug_flag: bool = False,
    runner: Runner | None = None,
) -> TalairachOutputs:
    """
    Front-end for MINC's mritotal to compute the Talairach transform mapping the
    input volume to the MNI305.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume.
        output_transform: Output transform file (xfm).
        log_flag: Specify log file. Default is outdir/talarach.log.
        debug_flag: Turn on debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TalairachOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TALAIRACH_METADATA)
    cargs = []
    cargs.append("mri_nu_correct.mni")
    cargs.extend([
        "-i",
        "-" + execution.input_file(input_volume)
    ])
    cargs.extend([
        "-xfm",
        "-" + output_transform
    ])
    if log_flag:
        cargs.append("--log")
    if debug_flag:
        cargs.append("--debug")
    ret = TalairachOutputs(
        root=execution.output_file("."),
        xfm_output=execution.output_file(output_transform),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TALAIRACH_METADATA",
    "TalairachOutputs",
    "talairach",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRDEGIBBS_METADATA = Metadata(
    id="07aa2daa1ce97b2b9113590497c38c7cb9570763.boutiques",
    name="mrdegibbs",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MrdegibbsConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MrdegibbsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrdegibbs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out: OutputPathType
    """the output image."""


def mrdegibbs(
    in_: InputPathType,
    out: str,
    axes: list[int] | None = None,
    nshifts: int | None = None,
    min_w: int | None = None,
    max_w: int | None = None,
    datatype: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MrdegibbsConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrdegibbsOutputs:
    """
    Remove Gibbs Ringing Artifacts.
    
    This application attempts to remove Gibbs ringing artefacts from MRI images
    using the method of local subvoxel-shifts proposed by Kellner et al. (see
    reference below for details).
    
    This command is designed to run on data directly after it has been
    reconstructed by the scanner, before any interpolation of any kind has taken
    place. You should not run this command after any form of motion correction
    (e.g. not after dwifslpreproc). Similarly, if you intend running dwidenoise,
    you should run denoising before this command to not alter the noise
    structure, which would impact on dwidenoise's performance.
    
    Note that this method is designed to work on images acquired with full
    k-space coverage. Running this method on partial Fourier ('half-scan') data
    may lead to suboptimal and/or biased results, as noted in the original
    reference below. There is currently no means of dealing with this; users
    should exercise caution when using this method on partial Fourier data, and
    inspect its output for any obvious artefacts.
    
    References:
    
    Kellner, E; Dhital, B; Kiselev, V.G & Reisert, M. Gibbs-ringing artifact
    removal based on local subvoxel-shifts. Magnetic Resonance in Medicine,
    2016, 76, 1574â€“1581.
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        in_: the input image.
        out: the output image.
        axes: select the slice axes (default: 0,1 - i.e. x-y).
        nshifts: discretization of subpixel spacing (default: 20).
        min_w: left border of window used for TV computation (default: 1).
        max_w: right border of window used for TV computation (default: 3).
        datatype: specify output image data type. Valid choices are: float32,\
            float32le, float32be, float64, float64le, float64be, int64, uint64,\
            int64le, uint64le, int64be, uint64be, int32, uint32, int32le, uint32le,\
            int32be, uint32be, int16, uint16, int16le, uint16le, int16be, uint16be,\
            cfloat32, cfloat32le, cfloat32be, cfloat64, cfloat64le, cfloat64be,\
            int8, uint8, bit.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrdegibbsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRDEGIBBS_METADATA)
    cargs = []
    cargs.append("mrdegibbs")
    if axes is not None:
        cargs.extend([
            "-axes",
            *map(str, axes)
        ])
    if nshifts is not None:
        cargs.extend([
            "-nshifts",
            str(nshifts)
        ])
    if min_w is not None:
        cargs.extend([
            "-minW",
            str(min_w)
        ])
    if max_w is not None:
        cargs.extend([
            "-maxW",
            str(max_w)
        ])
    if datatype is not None:
        cargs.extend([
            "-datatype",
            datatype
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(in_))
    cargs.append(out)
    ret = MrdegibbsOutputs(
        root=execution.output_file("."),
        out=execution.output_file(out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRDEGIBBS_METADATA",
    "MrdegibbsConfig",
    "MrdegibbsOutputs",
    "mrdegibbs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__4_DAVERAGE_METADATA = Metadata(
    id="539f6118b726725db3041382540750353fc522e5.boutiques",
    name="@4Daverage",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V4DaverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__4_daverage(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__4_daverage(
    output_prefix: str,
    runner: Runner | None = None,
) -> V4DaverageOutputs:
    """
    Script for computing average 3D+time bricks using 3Dcalc.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        output_prefix: Prefix for the output 3D+t brick.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V4DaverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__4_DAVERAGE_METADATA)
    cargs = []
    cargs.append("@4Daverage")
    cargs.append(output_prefix)
    cargs.append("[INPUT_FILES...]")
    ret = V4DaverageOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V4DaverageOutputs",
    "V__4_DAVERAGE_METADATA",
    "v__4_daverage",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_APPLY_TRANSFORMS_TO_POINTS_METADATA = Metadata(
    id="1ba8745cbb78f985d998ca462d13cc2627bbcd68.boutiques",
    name="antsApplyTransformsToPoints",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


@dataclasses.dataclass
class AntsApplyTransformsToPointsSingleTransform:
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("[TRANSFORM]")
        return cargs


@dataclasses.dataclass
class AntsApplyTransformsToPointsInverseTransform:
    transform_file: InputPathType
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.transform_file) + ",1")
        return cargs


class AntsApplyTransformsToPointsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_apply_transforms_to_points(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warped_points: OutputPathType
    """The output is the CSV file containing warped points."""


def ants_apply_transforms_to_points(
    input_: InputPathType,
    output: str,
    dimensionality: typing.Literal[2, 3] | None = None,
    precision: typing.Literal[0, 1] | None = None,
    forantsr: typing.Literal[0, 1] | None = None,
    transform: typing.Union[AntsApplyTransformsToPointsSingleTransform, AntsApplyTransformsToPointsInverseTransform] | None = None,
    runner: Runner | None = None,
) -> AntsApplyTransformsToPointsOutputs:
    """
    antsApplyTransformsToPoints, applied to an input image, transforms it according
    to a reference image and a transform (or a set of transforms). It reads in a CSV
    file with the first D columns defining the spatial location where the spatial
    location is defined in physical coordinates. The CSV file should have a header
    row.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_: Input CSV file with columns including x,y,z,t headers that\
            define the points in physical space, or a 2D .mha binary image file.
        output: Output the warped points to a CSV file.
        dimensionality: This option forces the points to be treated as a\
            specified-dimensionality.
        precision: Use double precision.
        forantsr: Set true for ANTsR IO.
        transform: Transform file(s) to apply to the input points. Uses an\
            inverse transform if specified as [transformFileName,1].
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsApplyTransformsToPointsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_APPLY_TRANSFORMS_TO_POINTS_METADATA)
    cargs = []
    cargs.append("antsApplyTransformsToPoints")
    if dimensionality is not None:
        cargs.extend([
            "--dimensionality",
            str(dimensionality)
        ])
    if precision is not None:
        cargs.extend([
            "--precision",
            str(precision)
        ])
    if forantsr is not None:
        cargs.extend([
            "--forantsr",
            str(forantsr)
        ])
    cargs.extend([
        "-i",
        execution.input_file(input_)
    ])
    cargs.extend([
        "-o",
        output
    ])
    if transform is not None:
        cargs.extend([
            "-t",
            *transform.run(execution)
        ])
    ret = AntsApplyTransformsToPointsOutputs(
        root=execution.output_file("."),
        warped_points=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_APPLY_TRANSFORMS_TO_POINTS_METADATA",
    "AntsApplyTransformsToPointsInverseTransform",
    "AntsApplyTransformsToPointsOutputs",
    "AntsApplyTransformsToPointsSingleTransform",
    "ants_apply_transforms_to_points",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_NITERS2FWHM_METADATA = Metadata(
    id="46d8d10a4cb889cf8adeaf5acc47511663af44b8.boutiques",
    name="mris_niters2fwhm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisNiters2fwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_niters2fwhm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_niters2fwhm(
    subject: str,
    hemi: str,
    surf: str,
    dof: float,
    niters: float,
    debug: bool = False,
    checkopts: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrisNiters2fwhmOutputs:
    """
    Convert number of iterations to full width at half maximum (FWHM) for surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        hemi: Hemisphere (e.g., lh or rh).
        surf: Surface type (e.g., white, pial).
        dof: Degrees of Freedom.
        niters: Maximum number of iterations.
        debug: Turn on debugging.
        checkopts: Don't run anything, just check options and exit.
        help_: Print out information on how to use this program.
        version: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisNiters2fwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_NITERS2FWHM_METADATA)
    cargs = []
    cargs.append("mris_niters2fwhm")
    cargs.extend([
        "--s",
        subject
    ])
    cargs.extend([
        "--h",
        hemi
    ])
    cargs.extend([
        "--surf",
        surf
    ])
    cargs.extend([
        "--dof",
        str(dof)
    ])
    cargs.extend([
        "--niters",
        str(niters)
    ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MrisNiters2fwhmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_NITERS2FWHM_METADATA",
    "MrisNiters2fwhmOutputs",
    "mris_niters2fwhm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_REVERSE_METADATA = Metadata(
    id="ecda44ba479fe2843ae6e0aa5b415f74e9dbf9f9.boutiques",
    name="mris_reverse",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisReverseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_reverse(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reversed_surface: OutputPathType
    """Reversed cortical surface file."""


def mris_reverse(
    input_surface: InputPathType,
    output_surface: str,
    runner: Runner | None = None,
) -> MrisReverseOutputs:
    """
    This tool reverses a cortical surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input cortical surface file.
        output_surface: Output cortical surface file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisReverseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_REVERSE_METADATA)
    cargs = []
    cargs.append("mris_reverse")
    cargs.append(execution.input_file(input_surface))
    cargs.append(output_surface)
    ret = MrisReverseOutputs(
        root=execution.output_file("."),
        reversed_surface=execution.output_file(output_surface + ".surf"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_REVERSE_METADATA",
    "MrisReverseOutputs",
    "mris_reverse",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UNPACK_IMA1_TCL_METADATA = Metadata(
    id="52c94b15732556feb79bbc32eda9530f12619cbc.boutiques",
    name="unpack_ima1.tcl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class UnpackIma1TclOutputs(typing.NamedTuple):
    """
    Output object returned when calling `unpack_ima1_tcl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    unpacked_files: OutputPathType
    """Unpacked files stored in the output directory"""


def unpack_ima1_tcl(
    input_directory: str,
    output_directory: str,
    runner: Runner | None = None,
) -> UnpackIma1TclOutputs:
    """
    A tool for unpacking images using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_directory: The directory containing the input files to be\
            unpacked.
        output_directory: The directory where the unpacked files will be\
            stored.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UnpackIma1TclOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UNPACK_IMA1_TCL_METADATA)
    cargs = []
    cargs.append("unpack_ima1.tcl")
    cargs.append(input_directory)
    cargs.append(output_directory)
    ret = UnpackIma1TclOutputs(
        root=execution.output_file("."),
        unpacked_files=execution.output_file(output_directory + "/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UNPACK_IMA1_TCL_METADATA",
    "UnpackIma1TclOutputs",
    "unpack_ima1_tcl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TALAIRACH_AVI_METADATA = Metadata(
    id="678baef5e6c260dfc7bf384b2e8261c153d14240.boutiques",
    name="talairach_avi",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TalairachAviOutputs(typing.NamedTuple):
    """
    Output object returned when calling `talairach_avi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_xfm_file: OutputPathType
    """Output transform file"""


def talairach_avi(
    input_file: InputPathType,
    output_xfm: str,
    atlas: str | None = None,
    log: str | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> TalairachAviOutputs:
    """
    Front-end for Avi Snyder's image registration tool. Computes the Talairach
    transform that maps the input volume to the MNI average_305.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume.
        output_xfm: Output transform file.
        atlas: Alternate target atlas (in freesurfer/average dir).
        log: Log file. Default is outdir/talairach_avi.log.
        debug: Turn on debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TalairachAviOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TALAIRACH_AVI_METADATA)
    cargs = []
    cargs.append("talairach_avi")
    cargs.extend([
        "--i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "--xfm",
        output_xfm
    ])
    if atlas is not None:
        cargs.extend([
            "--atlas",
            atlas
        ])
    if log is not None:
        cargs.extend([
            "--log",
            log
        ])
    if debug:
        cargs.append("--debug")
    ret = TalairachAviOutputs(
        root=execution.output_file("."),
        output_xfm_file=execution.output_file(output_xfm),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TALAIRACH_AVI_METADATA",
    "TalairachAviOutputs",
    "talairach_avi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TTO1_D_METADATA = Metadata(
    id="c4536089d729353b2214d75b62553c23db962d0e.boutiques",
    name="3dTto1D",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTto1DOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tto1_d(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output 1D time series file"""


def v_3d_tto1_d(
    input_dataset: InputPathType,
    method: str,
    automask: bool = False,
    mask: InputPathType | None = None,
    prefix: str | None = None,
    verbose: float | None = None,
    runner: Runner | None = None,
) -> V3dTto1DOutputs:
    """
    Collapse a 4D time series to a 1D time series.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Specify input dataset. This should be a set of 3D time\
            series. If the input is in 1D format, a transpose operator will\
            typically be required.
        method: Specify 4D to 1D conversion method. Methods include: enorm,\
            dvars, srms, shift_srms, mdiff, smdiff, 4095_count, 4095_frac,\
            4095_warn.
        automask: Restrict computation to automask.
        mask: Restrict computation to given mask.
        prefix: Specify output file. Default is stdout.
        verbose: Specify verbose level. Default is 1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTto1DOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TTO1_D_METADATA)
    cargs = []
    cargs.append("3dTto1D")
    cargs.extend([
        "-input",
        execution.input_file(input_dataset)
    ])
    cargs.extend([
        "-method",
        method
    ])
    if automask:
        cargs.append("-automask")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if verbose is not None:
        cargs.extend([
            "-verb",
            str(verbose)
        ])
    ret = V3dTto1DOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix) if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTto1DOutputs",
    "V_3D_TTO1_D_METADATA",
    "v_3d_tto1_d",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_4D_SLICES_TO_3D_VOL_METADATA = Metadata(
    id="e85dbe20324eef240907de23abb203630c5e1180.boutiques",
    name="@djunct_4d_slices_to_3d_vol",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunct4dSlicesTo3dVolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_4d_slices_to_3d_vol(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output file generated by the tool"""


def v__djunct_4d_slices_to_3d_vol(
    do_something: bool = False,
    runner: Runner | None = None,
) -> VDjunct4dSlicesTo3dVolOutputs:
    """
    Tool description goes here.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        do_something: Do something really useful.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunct4dSlicesTo3dVolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_4D_SLICES_TO_3D_VOL_METADATA)
    cargs = []
    cargs.append("@djunct_4d_slices_to_3d_vol")
    if do_something:
        cargs.append("-do-something")
    ret = VDjunct4dSlicesTo3dVolOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("output_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunct4dSlicesTo3dVolOutputs",
    "V__DJUNCT_4D_SLICES_TO_3D_VOL_METADATA",
    "v__djunct_4d_slices_to_3d_vol",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REGDAT2XFM_METADATA = Metadata(
    id="b9432995881f050a69f7f6321a3344dd584bf012.boutiques",
    name="regdat2xfm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Regdat2xfmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `regdat2xfm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def regdat2xfm(
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> Regdat2xfmOutputs:
    """
    This tool has been removed from the current version of FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file (registration data).
        output_file: Output file (transformation matrix).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Regdat2xfmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REGDAT2XFM_METADATA)
    cargs = []
    cargs.append("regdat2xfm")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = Regdat2xfmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REGDAT2XFM_METADATA",
    "Regdat2xfmOutputs",
    "regdat2xfm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_EDU_01_SCALE_METADATA = Metadata(
    id="421ae3b97be6019b8194c6bf2db5b0b7024dbd25.boutiques",
    name="3dEdu_01_scale",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dEdu01ScaleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_edu_01_scale(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output scaled and/or masked copy of the [0]th volume of the input
    dataset"""


def v_3d_edu_01_scale(
    input_: InputPathType,
    mask: InputPathType | None = None,
    mult_factors: list[float] | None = None,
    option_flag: bool = False,
    runner: Runner | None = None,
) -> V3dEdu01ScaleOutputs:
    """
    Educational program to create a new AFNI program. Scales and masks dataset
    volumes.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Input dataset.
        mask: Mask dataset on same grid/data structure as the input dataset.
        mult_factors: Numerical factors for multiplying each voxel; each voxel\
            is multiplied by both A and B.
        option_flag: Option flag to do something.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dEdu01ScaleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_EDU_01_SCALE_METADATA)
    cargs = []
    cargs.append("3dEdu_01_scale")
    cargs.append(execution.input_file(input_))
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if mult_factors is not None:
        cargs.extend([
            "-mult_facs",
            *map(str, mult_factors)
        ])
    if option_flag:
        cargs.append("-some_opt")
    ret = V3dEdu01ScaleOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("OUT_edu_[1-9]*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dEdu01ScaleOutputs",
    "V_3D_EDU_01_SCALE_METADATA",
    "v_3d_edu_01_scale",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBJECT_OLD_SKULL_STRIP_METADATA = Metadata(
    id="abc48359fac304f034867897b978186bcd82c5e7.boutiques",
    name="segment_subject_old_skull_strip",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubjectOldSkullStripOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subject_old_skull_strip(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_xfm_file: OutputPathType
    """Resulting output xfm file"""
    log_output_file: OutputPathType | None
    """Generated log file"""


def segment_subject_old_skull_strip(
    input_volume: InputPathType,
    output_xfm: str,
    log_file: str | None = None,
    help_flag: bool = False,
    debug_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> SegmentSubjectOldSkullStripOutputs:
    """
    Front-end for MINCs mritotal for computing the talairach transform that maps the
    input volume to the MNI305.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file.
        output_xfm: Output xfm file.
        log_file: Log file. Default is outdir/talarach.log.
        help_flag: Print help and exit.
        debug_flag: Turn on debugging.
        version_flag: Print version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubjectOldSkullStripOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBJECT_OLD_SKULL_STRIP_METADATA)
    cargs = []
    cargs.append("mri_nu_correct.mni")
    cargs.extend([
        "-i",
        "-" + execution.input_file(input_volume)
    ])
    cargs.extend([
        "-xfm",
        "-" + output_xfm
    ])
    if log_file is not None:
        cargs.extend([
            "--log",
            log_file
        ])
    if help_flag:
        cargs.append("--help")
    if debug_flag:
        cargs.append("--debug")
    if version_flag:
        cargs.append("--version")
    ret = SegmentSubjectOldSkullStripOutputs(
        root=execution.output_file("."),
        output_xfm_file=execution.output_file(output_xfm),
        log_output_file=execution.output_file(log_file) if (log_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBJECT_OLD_SKULL_STRIP_METADATA",
    "SegmentSubjectOldSkullStripOutputs",
    "segment_subject_old_skull_strip",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BBMASK_METADATA = Metadata(
    id="064153f645343fa44a6da922e9a35232f8ea8522.boutiques",
    name="bbmask",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BbmaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bbmask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mask_output_file: OutputPathType
    """Output mask volume"""
    src_output_file: OutputPathType
    """Output reduced volume(s)"""
    registration_output_file: OutputPathType
    """Output registration file"""
    regheader_output_file: OutputPathType
    """Output registration file from regheader"""
    sub2src_output_file: OutputPathType
    """Output file for sub2src registration"""


def bbmask(
    mask: list[InputPathType],
    src_volumes: list[InputPathType] | None = None,
    npad: float | None = None,
    registration: list[InputPathType] | None = None,
    regheader: InputPathType | None = None,
    sub2src: InputPathType | None = None,
    runner: Runner | None = None,
) -> BbmaskOutputs:
    """
    Tool to create a volume with a smaller field of view by creating a bounding box
    that encompasses a mask.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        mask: Input and output for the mask volume.
        src_volumes: Input and output volumes to be reduced to the bounding\
            box.
        npad: Number of voxels to expand the bounding box.
        registration: Input and output registration files.
        regheader: Output registration file from header.
        sub2src: Output file for sub-source registration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BbmaskOutputs`).
    """
    if (len(mask) != 2): 
        raise ValueError(f"Length of 'mask' must be 2 but was {len(mask)}")
    if src_volumes is not None and not (2 <= len(src_volumes)): 
        raise ValueError(f"Length of 'src_volumes' must be greater than 2 but was {len(src_volumes)}")
    if registration is not None and (len(registration) != 2): 
        raise ValueError(f"Length of 'registration' must be 2 but was {len(registration)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(BBMASK_METADATA)
    cargs = []
    cargs.append("bbmask")
    cargs.extend([
        "--mask",
        *[execution.input_file(f) for f in mask]
    ])
    if src_volumes is not None:
        cargs.extend([
            "--src",
            *[execution.input_file(f) for f in src_volumes]
        ])
    if npad is not None:
        cargs.extend([
            "--npad",
            str(npad)
        ])
    if registration is not None:
        cargs.extend([
            "--reg",
            *[execution.input_file(f) for f in registration]
        ])
    if regheader is not None:
        cargs.extend([
            "--regheader",
            execution.input_file(regheader)
        ])
    if sub2src is not None:
        cargs.extend([
            "--sub2src",
            execution.input_file(sub2src)
        ])
    ret = BbmaskOutputs(
        root=execution.output_file("."),
        mask_output_file=execution.output_file("[MASK_OUTPUT]"),
        src_output_file=execution.output_file("[SRC_OUTPUT]"),
        registration_output_file=execution.output_file("[REG_OUTPUT]"),
        regheader_output_file=execution.output_file("[REG_HEADER_OUTPUT]"),
        sub2src_output_file=execution.output_file("[SUB2SRC_OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BBMASK_METADATA",
    "BbmaskOutputs",
    "bbmask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_EMPTY_METADATA = Metadata(
    id="458e0d6419fbf58fb595b4f42ae970422fb2886a.boutiques",
    name="3dEmpty",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dEmptyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_empty(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType | None
    """Output empty dataset header file"""


def v_3d_empty(
    prefix: str | None = None,
    geometry: str | None = None,
    nxyz: list[float] | None = None,
    nt_: float | None = None,
    runner: Runner | None = None,
) -> V3dEmptyOutputs:
    """
    Tool to create an 'empty' dataset .HEAD file.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Prefix name for output file (default = 'Empty').
        geometry: Set the 3D geometry of the grid using a string of the form\
            'MATRIX(a11,a12,a13,a14,a21,a22,a23,a24,a31,a32,a33,a34):nx,ny,nz'.
        nxyz: Set number of voxels to 'x', 'y', and 'z' along the 3 axes\
            [defaults=64].
        nt_: Number of time points [default=1].
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dEmptyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_EMPTY_METADATA)
    cargs = []
    cargs.append("3dEmpty")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if geometry is not None:
        cargs.extend([
            "-geometry",
            geometry
        ])
    if nxyz is not None:
        cargs.extend([
            "-nxyz",
            *map(str, nxyz)
        ])
    if nt_ is not None:
        cargs.extend([
            "-nt",
            str(nt_)
        ])
    ret = V3dEmptyOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(prefix + ".HEAD") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dEmptyOutputs",
    "V_3D_EMPTY_METADATA",
    "v_3d_empty",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSCALC_METADATA = Metadata(
    id="8980bc90eda2781be7235010d28f030a03b7741c.boutiques",
    name="fscalc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FscalcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fscalc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_vol: OutputPathType
    """Resulting output volume from the operations specified."""


def fscalc(
    input1: str,
    operation: str,
    output_file: str,
    input2: str | None = None,
    output_data_type: str | None = None,
    debug: bool = False,
    tmpdir: str | None = None,
    nocleanup: bool = False,
    log_file: str | None = None,
    runner: Runner | None = None,
) -> FscalcOutputs:
    """
    A frontend tool to perform mathematical operations on volumes/surfaces of data
    using mris_calc.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input1: First input image or constant.
        operation: Operation to perform between input volumes.
        output_file: Output volume file.
        input2: Second input image or constant. Optional for some unary\
            operations.
        output_data_type: Specify output data type (uchar, short, int, float).
        debug: Enable debug mode.
        tmpdir: Temporary directory for processing.
        nocleanup: Prevent cleanup of temporary files.
        log_file: Specify a log file for operation log.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FscalcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSCALC_METADATA)
    cargs = []
    cargs.append("fscalc")
    cargs.append(input1)
    cargs.append(operation)
    if input2 is not None:
        cargs.append(input2)
    cargs.extend([
        "--o",
        output_file
    ])
    if output_data_type is not None:
        cargs.extend([
            "--odt",
            output_data_type
        ])
    if debug:
        cargs.append("--debug")
    if tmpdir is not None:
        cargs.extend([
            "--tmpdir",
            tmpdir
        ])
    if nocleanup:
        cargs.append("--nocleanup")
    if log_file is not None:
        cargs.extend([
            "--log",
            log_file
        ])
    ret = FscalcOutputs(
        root=execution.output_file("."),
        result_vol=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSCALC_METADATA",
    "FscalcOutputs",
    "fscalc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DNVALS_METADATA = Metadata(
    id="d7ef1cfaf0a24a61ba64fc6419199d6758fdcf7a.boutiques",
    name="3dnvals",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dnvalsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dnvals(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3dnvals(
    datasets: list[InputPathType],
    all_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> V3dnvalsOutputs:
    """
    Tool to print the number of sub-bricks in a 3D dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        datasets: Input 3D dataset(s).
        all_flag: Print out all 4 dimensions: Nx, Ny, Nz, Nvals.
        verbose_flag: Print the header name of the dataset first.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dnvalsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DNVALS_METADATA)
    cargs = []
    cargs.append("3dnvals")
    cargs.extend([execution.input_file(f) for f in datasets])
    if all_flag:
        cargs.append("-all")
    if verbose_flag:
        cargs.append("-verbose")
    ret = V3dnvalsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dnvalsOutputs",
    "V_3DNVALS_METADATA",
    "v_3dnvals",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RANDOMISE_METADATA = Metadata(
    id="09ec23a1b6f8029fbc99416ba9beba51f568a0ef.boutiques",
    name="randomise",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class RandomiseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `randomise(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    f_corrected_p_files: OutputPathType
    """F contrast fwe (family-wise error) corrected p values files."""
    f_p_files: OutputPathType
    """F contrast uncorrected p values files."""
    fstat_files: OutputPathType
    """F contrast raw statistic."""
    t_corrected_p_files: OutputPathType
    """T contrast fwe (family-wise error) corrected p values files."""
    t_p_files: OutputPathType
    """F contrast uncorrected p values files."""
    tstat_files: OutputPathType
    """T contrast raw statistic."""


def randomise(
    in_file: InputPathType,
    base_name: str | None = "randomise",
    design_mat: InputPathType | None = None,
    tcon: InputPathType | None = None,
    c_thresh: float | None = None,
    cm_thresh: float | None = None,
    demean: bool = False,
    f_c_thresh: float | None = None,
    f_cm_thresh: float | None = None,
    f_only: bool = False,
    fcon: InputPathType | None = None,
    mask: InputPathType | None = None,
    num_perm: int | None = None,
    one_sample_group_mean: bool = False,
    output_type: typing.Literal["NIFTI", "NIFTI_PAIR", "NIFTI_GZ", "NIFTI_PAIR_GZ"] | None = None,
    p_vec_n_dist_files: bool = False,
    raw_stats_imgs: bool = False,
    seed: int | None = None,
    show_info_parallel_mode: bool = False,
    show_total_perms: bool = False,
    tfce: bool = False,
    tfce2_d: bool = False,
    tfce_c: float | None = None,
    tfce_e: float | None = None,
    tfce_h: float | None = None,
    var_smooth: int | None = None,
    vox_p_values: bool = False,
    x_block_labels: InputPathType | None = None,
    runner: Runner | None = None,
) -> RandomiseOutputs:
    """
    FSL Randomise: feeds the 4D projected FA data into GLM modelling and
    thresholding in order to find voxels which correlate with your model.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        in_file: 4d input file.
        base_name: The rootname that all generated files will have.
        design_mat: Design matrix file.
        tcon: T contrasts file.
        c_thresh: Carry out cluster-based thresholding.
        cm_thresh: Carry out cluster-mass-based thresholding.
        demean: Demean data temporally before model fitting.
        f_c_thresh: Carry out f cluster thresholding.
        f_cm_thresh: Carry out f cluster-mass thresholding.
        f_only: Calculate f-statistics only.
        fcon: F contrasts file.
        mask: Mask image.
        num_perm: Number of permutations (default 5000, set to 0 for\
            exhaustive).
        one_sample_group_mean: Perform 1-sample group-mean test instead of\
            generic permutation test.
        output_type: 'nifti' or 'nifti_pair' or 'nifti_gz' or 'nifti_pair_gz'.\
            Fsl output type.
        p_vec_n_dist_files: Output permutation vector and null distribution\
            text files.
        raw_stats_imgs: Output raw ( unpermuted ) statistic images.
        seed: Specific integer seed for random number generator.
        show_info_parallel_mode: Print out information required for parallel\
            mode and exit.
        show_total_perms: Print out how many unique permutations would be\
            generated and exit.
        tfce: Carry out threshold-free cluster enhancement.
        tfce2_d: Carry out threshold-free cluster enhancement with 2d\
            optimisation.
        tfce_c: Tfce connectivity (6 or 26; default=6).
        tfce_e: Tfce extent parameter (default=0.5).
        tfce_h: Tfce height parameter (default=2).
        var_smooth: Use variance smoothing (std is in mm).
        vox_p_values: Output voxelwise (corrected and uncorrected) p-value\
            images.
        x_block_labels: Exchangeability block labels file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RandomiseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RANDOMISE_METADATA)
    cargs = []
    cargs.append("randomise")
    cargs.extend([
        "-i",
        execution.input_file(in_file)
    ])
    if base_name is not None:
        cargs.extend([
            "-o",
            base_name
        ])
    if design_mat is not None:
        cargs.extend([
            "-d",
            execution.input_file(design_mat)
        ])
    if tcon is not None:
        cargs.extend([
            "-t",
            execution.input_file(tcon)
        ])
    if c_thresh is not None:
        cargs.extend([
            "-c",
            str(c_thresh)
        ])
    if cm_thresh is not None:
        cargs.extend([
            "-C",
            str(cm_thresh)
        ])
    if demean:
        cargs.append("-D")
    if f_c_thresh is not None:
        cargs.extend([
            "-F",
            str(f_c_thresh)
        ])
    if f_cm_thresh is not None:
        cargs.extend([
            "-S",
            str(f_cm_thresh)
        ])
    if f_only:
        cargs.append("--fonly")
    if fcon is not None:
        cargs.extend([
            "-f",
            execution.input_file(fcon)
        ])
    if mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask)
        ])
    if num_perm is not None:
        cargs.extend([
            "-n",
            str(num_perm)
        ])
    if one_sample_group_mean:
        cargs.append("-1")
    if output_type is not None:
        cargs.append(output_type)
    if p_vec_n_dist_files:
        cargs.append("-P")
    if raw_stats_imgs:
        cargs.append("-R")
    if seed is not None:
        cargs.append("--seed=" + str(seed))
    if show_info_parallel_mode:
        cargs.append("-Q")
    if show_total_perms:
        cargs.append("-q")
    if tfce:
        cargs.append("-T")
    if tfce2_d:
        cargs.append("--T2")
    if tfce_c is not None:
        cargs.append("--tfce_C=" + str(tfce_c))
    if tfce_e is not None:
        cargs.append("--tfce_E=" + str(tfce_e))
    if tfce_h is not None:
        cargs.append("--tfce_H=" + str(tfce_h))
    if var_smooth is not None:
        cargs.extend([
            "-v",
            str(var_smooth)
        ])
    if vox_p_values:
        cargs.append("-x")
    if x_block_labels is not None:
        cargs.extend([
            "-e",
            execution.input_file(x_block_labels)
        ])
    ret = RandomiseOutputs(
        root=execution.output_file("."),
        f_corrected_p_files=execution.output_file("f_corrected_p_files"),
        f_p_files=execution.output_file("f_p_files"),
        fstat_files=execution.output_file("fstat_files"),
        t_corrected_p_files=execution.output_file("t_corrected_p_files"),
        t_p_files=execution.output_file("t_p_files"),
        tstat_files=execution.output_file("tstat_files"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RANDOMISE_METADATA",
    "RandomiseOutputs",
    "randomise",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SURFACEMASK_METADATA = Metadata(
    id="b54f5cc796265da710c425a288cee6461dd77a00.boutiques",
    name="mri_surfacemask",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSurfacemaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_surfacemask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume_file: OutputPathType
    """The resulting surface-masked volume"""


def mri_surfacemask(
    input_volume: InputPathType,
    input_surface: InputPathType,
    output_volume: str,
    runner: Runner | None = None,
) -> MriSurfacemaskOutputs:
    """
    Tool to produce a new volume where all pixels outside the surface are set to
    zero.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume which will be masked.
        input_surface: Surface file used for masking the volume.
        output_volume: Output volume file where pixels outside the surface are\
            set to zero.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSurfacemaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SURFACEMASK_METADATA)
    cargs = []
    cargs.append("mri_surfacemask")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(input_surface))
    cargs.append(output_volume)
    ret = MriSurfacemaskOutputs(
        root=execution.output_file("."),
        output_volume_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SURFACEMASK_METADATA",
    "MriSurfacemaskOutputs",
    "mri_surfacemask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_VESSEL_SEGMENT_METADATA = Metadata(
    id="6f3e4e326255b57c2dfda638c29cce61255996ef.boutiques",
    name="mri_vessel_segment",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriVesselSegmentOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_vessel_segment(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmented_output: OutputPathType
    """Segmented vessel output file"""


def mri_vessel_segment(
    t1_image: InputPathType,
    t2_image: InputPathType,
    aseg_file: InputPathType,
    output_file: str,
    shape_flag: bool = False,
    runner: Runner | None = None,
) -> MriVesselSegmentOutputs:
    """
    MRI vessel segmentation tool.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        t1_image: T1-weighted input image.
        t2_image: T2-weighted input image.
        aseg_file: Anatomical segmentation file.
        output_file: Output file.
        shape_flag: Use shape constraints during segmentation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriVesselSegmentOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_VESSEL_SEGMENT_METADATA)
    cargs = []
    cargs.append("mri_vessel_segment")
    cargs.extend([
        "-t1",
        execution.input_file(t1_image)
    ])
    cargs.extend([
        "-t2",
        execution.input_file(t2_image)
    ])
    cargs.extend([
        "-aseg",
        execution.input_file(aseg_file)
    ])
    cargs.extend([
        "-o",
        output_file
    ])
    if shape_flag:
        cargs.append("--shape")
    ret = MriVesselSegmentOutputs(
        root=execution.output_file("."),
        segmented_output=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_VESSEL_SEGMENT_METADATA",
    "MriVesselSegmentOutputs",
    "mri_vessel_segment",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SET_STRUCTURE_METADATA = Metadata(
    id="b34214858feec5e1f1ef5db8d7db2f2cbe0976d1.boutiques",
    name="set-structure",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SetStructureOutputs(typing.NamedTuple):
    """
    Output object returned when calling `set_structure(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def set_structure(
    data_file: str,
    structure: str,
    opt_surface_type_type: str | None = None,
    opt_surface_secondary_type_secondary_type: str | None = None,
    runner: Runner | None = None,
) -> SetStructureOutputs:
    """
    Set structure of a data file.
    
    The existing file is modified and rewritten to the same filename. Valid
    values for the structure name are:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT
    
    Valid names for the surface type are:
    
    UNKNOWN
    RECONSTRUCTION
    ANATOMICAL
    INFLATED
    VERY_INFLATED
    SPHERICAL
    SEMI_SPHERICAL
    ELLIPSOID
    FLAT
    HULL
    
    Valid names for the surface secondary type are:
    
    INVALID
    GRAY_WHITE
    MIDTHICKNESS
    PIAL
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        data_file: the file to set the structure of.
        structure: the structure to set the file to.
        opt_surface_type_type: set the type of a surface (only used if file is\
            a surface file): name of surface type.
        opt_surface_secondary_type_secondary_type: set the secondary type of a\
            surface (only used if file is a surface file): name of surface\
            secondary type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SetStructureOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SET_STRUCTURE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-set-structure")
    cargs.append(data_file)
    cargs.append(structure)
    if opt_surface_type_type is not None:
        cargs.extend([
            "-surface-type",
            opt_surface_type_type
        ])
    if opt_surface_secondary_type_secondary_type is not None:
        cargs.extend([
            "-surface-secondary-type",
            opt_surface_secondary_type_secondary_type
        ])
    ret = SetStructureOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SET_STRUCTURE_METADATA",
    "SetStructureOutputs",
    "set_structure",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ASEGSTATSDIFF_METADATA = Metadata(
    id="10487227e273c61c9beadcb9b38d15804d6724e3.boutiques",
    name="asegstatsdiff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class AsegstatsdiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `asegstatsdiff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    asegstats_output: OutputPathType | None
    """Output table with percent differences added."""


def asegstatsdiff(
    subject1: str,
    subject2: str,
    outdir: str | None = None,
    runner: Runner | None = None,
) -> AsegstatsdiffOutputs:
    """
    Compute and report percentage differences in aseg morphometry data between two
    subjects.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject1: The first subject to be compared.
        subject2: The second subject to be compared.
        outdir: Optionally specify a directory to write the output\
            asegstats.txt.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AsegstatsdiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ASEGSTATSDIFF_METADATA)
    cargs = []
    cargs.append("asegstatsdiff")
    cargs.append(subject1)
    if outdir is not None:
        cargs.append(subject2 + outdir)
    ret = AsegstatsdiffOutputs(
        root=execution.output_file("."),
        asegstats_output=execution.output_file(outdir + "/asegstats.txt") if (outdir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ASEGSTATSDIFF_METADATA",
    "AsegstatsdiffOutputs",
    "asegstatsdiff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COPY_PARAMS_METADATA = Metadata(
    id="04ff7772827c0d2910e0be4cad90ac6d7da938f2.boutiques",
    name="mri_copy_params",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCopyParamsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_copy_params(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Output volume file with parameters copied."""


def mri_copy_params(
    in_vol: InputPathType,
    template_vol: InputPathType,
    out_vol: str,
    size_flag: bool = False,
    runner: Runner | None = None,
) -> MriCopyParamsOutputs:
    """
    A tool to replace the volume parameters of an input volume with those of a
    template volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        in_vol: Input volume file whose parameters will be replaced.
        template_vol: Template volume file whose parameters will be copied.
        out_vol: Output volume file with replaced parameters.
        size_flag: Force copying of voxel sizes when resolutions vary.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCopyParamsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COPY_PARAMS_METADATA)
    cargs = []
    cargs.append("mri_copy_params")
    cargs.append(execution.input_file(in_vol))
    cargs.append(execution.input_file(template_vol))
    cargs.append(out_vol)
    if size_flag:
        cargs.append("--size")
    ret = MriCopyParamsOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(out_vol),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COPY_PARAMS_METADATA",
    "MriCopyParamsOutputs",
    "mri_copy_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SUMA_GLXDINO_METADATA = Metadata(
    id="010ab925596263ceb26cb004e13fc1698878aefc.boutiques",
    name="SUMA_glxdino",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SumaGlxdinoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `suma_glxdino(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def suma_glxdino(
    verbose: bool = False,
    runner: Runner | None = None,
) -> SumaGlxdinoOutputs:
    """
    A simple openGL test program using GLX. If it does not run, then SUMA certainly
    won't.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        verbose: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SumaGlxdinoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SUMA_GLXDINO_METADATA)
    cargs = []
    cargs.append("SUMA_glxdino")
    if verbose:
        cargs.append("-v")
    ret = SumaGlxdinoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SUMA_GLXDINO_METADATA",
    "SumaGlxdinoOutputs",
    "suma_glxdino",
]
